/******************************************************************************
* File Name: main_cm4.c
*
* Version 2.0
*
* Description:
*  This code example demonstrates the use of GPIO configured as an input pin to
*  generate interrupts on CM4 CPU in PSoC 6 MCU.
*
* Related Document: CE219521.pdf
*
* Hardware Dependency: See CE219521.pdf
*
*******************************************************************************
* Copyright (2017-2018), Cypress Semiconductor Corporation. All rights reserved.
*******************************************************************************
* This software, including source code, documentation and related materials
* (“Software”), is owned by Cypress Semiconductor Corporation or one of its
* subsidiaries (“Cypress”) and is protected by and subject to worldwide patent
* protection (United States and foreign), United States copyright laws and
* international treaty provisions. Therefore, you may use this Software only
* as provided in the license agreement accompanying the software package from
* which you obtained this Software (“EULA”).
*
* If no EULA applies, Cypress hereby grants you a personal, nonexclusive,
* non-transferable license to copy, modify, and compile the Software source
* code solely for use in connection with Cypress’s integrated circuit products.
* Any reproduction, modification, translation, compilation, or representation
* of this Software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: THIS SOFTWARE IS PROVIDED AS-IS, WITH NO WARRANTY OF ANY KIND,
* EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Cypress
* reserves the right to make changes to the Software without notice. Cypress
* does not assume any liability arising out of the application or use of the
* Software or any product or circuit described in the Software. Cypress does
* not authorize its products for use in any products where a malfunction or
* failure of the Cypress product may reasonably be expected to result in
* significant property damage, injury or death (“High Risk Product”). By
* including Cypress’s product in a High Risk Product, the manufacturer of such
* system or application assumes all risk of such use and in doing so agrees to
* indemnify Cypress against all liability.
*******************************************************************************/
#include "project.h"

/* Macros for configuring project functionality */
#define DELAY_SHORT             (250)   /* milliseconds */
#define DELAY_LONG              (500)   /* milliseconds */

#define LED_BLINK_COUNT		    (1)

#define LED_ON                  (0)
#define LED_OFF                 (1)

#define SWITCH_INTR_PRIORITY	(3u)

/* Global variable */
uint32_t interrupt_flag = false;

/*******************************************************************************
* Function Name: void Switch_ISR(void)
********************************************************************************
*
* Summary:
*  This function is executed when GPIO interrupt is triggered.
*
* Parameters: None
*
* Return: None
*
*******************************************************************************/
void Isr_switch(void)
{
    /* Clears the triggered pin interrupt */
	Cy_GPIO_ClearInterrupt(KIT_BTN1_PORT, KIT_BTN1_NUM);
	NVIC_ClearPendingIRQ(SysInt_Switch_cfg.intrSrc);
    
    /* Set interrupt flag */
	interrupt_flag = true;
}

/*******************************************************************************
* Function Name: main
********************************************************************************
*
* Summary:
*  System entrance point. This function configures and initializes the GPIO
*  interrupt, update the delay on every GPIO interrupt, blinks the LED and enter
*  in deepsleep mode.
*
* Parameters: None
*
* Return: int
*
*******************************************************************************/

int main(void)
{
	uint32_t count = 0;
	uint32_t delayMs = DELAY_LONG;

    /* Enale interrupt */
    __enable_irq();
 
    /* Initialize and enable GPIO interrupt assigned to CM0+ */
	Cy_SysInt_Init(&SysInt_Switch_cfg, Isr_switch);
	NVIC_ClearPendingIRQ(SysInt_Switch_cfg.intrSrc);
	NVIC_EnableIRQ(SysInt_Switch_cfg.intrSrc);
        
	for(;;)
	{
        /* Check the interrupt status */
		if(true == interrupt_flag)
		{
			interrupt_flag = false;
            
            /* Update the LED blink interval */
			Cy_GPIO_Inv (KIT_LED_RED_PORT, KIT_LED_RED_NUM);
		    }

      }
}

/* [] END OF FILE */
